@@ -128,29 +128,39 @@ if os.name == 'posix':
     incdir = libdir = None
     if not BERKELEYDB_DIR and not BERKELEYDB_LIBDIR and not BERKELEYDB_INCDIR:
         # Supported Berkeley DB versions, in order of preference.
-        db_ver_list = ((5, 2), (5, 1), (5, 0),
-                (4, 8), (4, 7), (4, 6), (4, 5), (4, 4), (4, 3), (4, 2))
+        db_ver_list = ((5, 3), (5, 2), (5, 1), (5, 0),
+                (4, 8), (4, 7), (4, 6), (4, 5), (4, 4), (4, 3))
 
         # construct a list of paths to look for the header file in on
         # top of the normal inc_dirs.
         db_inc_paths = []
-        db_major = {}  # We can use a SET when we drop Python 2.3 support
+        db_major = set()
+        bitness = ""
+        import platform
+        if (platform.architecture()[0] == "64bit") and \
+           (platform.platform(True, True).startswith("Solaris-")) :
+               bitness = "/64"
+
         for major, minor in db_ver_list :
             if major not in db_major :
-                db_major[major] = None
+                db_major.add(major)
                 db_inc_paths.extend([
-                    '/usr/include/db%d' % major,
-                    '/usr/local/include/db%d' %major,
-                    '/opt/sfw/include/db%d' %major,
-                    '/sw/include/db%d' %major,
+                    '/usr/include/db%d%s' %(major, bitness),
+                    '/usr/local/include/db%d%s' %(major, bitness),
+                    '/opt/sfw/include/db%d%s' %(major, bitness),
+                    '/sw/include/db%d%s' %(major, bitness),
                     ])
 
-            db_inc_paths.append('/usr/include/db%d%d' % (major, minor))
-            db_inc_paths.append('/usr/local/BerkeleyDB.%d.%d/include' % (major,
-                minor))
-            db_inc_paths.append('/usr/local/include/db%d%d' % (major, minor))
-            db_inc_paths.append('/pkg/db-%d.%d/include' % (major, minor))
-            db_inc_paths.append('/opt/db-%d.%d/include' % (major, minor))
+            db_inc_paths.append('/usr/include/db%d%d%s' % \
+                (major, minor, bitness))
+            db_inc_paths.append('/usr/local/BerkeleyDB.%d.%d%s/include' % \
+                (major, minor, bitness))
+            db_inc_paths.append('/usr/local/include/db%d%d%s' % \
+                (major, minor, bitness))
+            db_inc_paths.append('/pkg/db-%d.%d%s/include' % \
+                (major, minor, bitness))
+            db_inc_paths.append('/opt/db-%d.%d%s/include' % \
+                (major, minor, bitness))
 
         db_ver_inc_map = {}
 
@@ -368,7 +378,7 @@ documentation as appropriate.
 pybsddb.htm>`__ --
 `Documentation <http://www.jcea.es/programacion/
 pybsddb_doc/>`__ --
-`Mailing List <http://mailman.jcea.es/listinfo/pybsddb>`__
+`Mailing List <https://mailman.jcea.es/listinfo/pybsddb>`__
 """,
 
       author = 'Jesus Cea, Robin Dunn, Gregory P. Smith, Andrew Kuchling, Barry Warsaw',
@@ -404,7 +414,6 @@ pybsddb_doc/>`__ --
                     'Topic :: Software Development',
                     'Topic :: System :: Clustering',
                     'Programming Language :: Python :: 2',
-                    'Programming Language :: Python :: 2.3',
                     'Programming Language :: Python :: 2.4',
                     'Programming Language :: Python :: 2.5',
                     'Programming Language :: Python :: 2.6',
@@ -412,5 +421,7 @@ pybsddb_doc/>`__ --
                     'Programming Language :: Python :: 3',
                     'Programming Language :: Python :: 3.1',
                     'Programming Language :: Python :: 3.2',
+                    'Programming Language :: Python :: 3.3',
                     ],
       )
+
