@@ -19,8 +19,7 @@ Options:
 -b
     Run "python setup.py build" before running tests, where "python" is the
     version of python used to run test.py.  Highly recommended.  Tests will be
-    run from the build directory.  (Note: In Python < 2.3 the -q flag is
-    added to the setup.py command line.)
+    run from the build directory.
 
 -B
     Run "python setup.py build_ext -i" before running tests.  Tests will be
@@ -429,6 +428,7 @@ def runner(files, test_filter, debug):
             pdb.post_mortem(sys.exc_info()[2])
         else:
             raise
+    return r
 
 
 def main(module_filter, test_filter):
@@ -450,7 +450,7 @@ def main(module_filter, test_filter):
         gui_runner(files, test_filter)
     elif LOOP:
         while True:
-            runner(files, test_filter, debug)
+            r = runner(files, test_filter, debug)
     elif TRACE:
         coverdir = os.path.join(os.getcwd(), "coverage")
         import trace
@@ -461,7 +461,9 @@ def main(module_filter, test_filter):
         r = tracer.results()
         r.write_results(show_missing=True, summary=True, coverdir=coverdir)
     else:
-        runner(files, test_filter, debug)
+        r = runner(files, test_filter, debug)
+    bad = r.errors + r.failures
+    return bad
 
 
 def process_args(argv=None):
@@ -559,11 +561,7 @@ def process_args(argv=None):
 
     # Do the builds
     if build:
-        # Python 2.3 is more sane in its non -q output
-        qflag = '-q'
-        if sys.hexversion >= 0x02030000:
-            qflag = ''
-        cmd = sys.executable + ' setup.py ' + qflag + ' build'
+        cmd = sys.executable + ' setup.py build'
         if build_inplace:
             cmd += '_ext -i'
         sts = os.system(cmd)
